@@ -2,11 +2,14 @@
 #' @title Filter temporally and spatially exact duplicates
 #' @description Function to filter temporally and spatially exact locations in tracking data.
 #' @param sdata A data frame containing columns with the following headers: "id", "DateTime", "lat", "lon", "qi". 
-#' The function filters the input data by the unique "id". 
-#' "DateTime" is date & time in class \code{\link[base]{POSIXct}}. 
+#' See the data \code{\link{turtle}} for an example.
+#' The function filters the input data by a unique "id" (e.g. transmitter number, identifier for each animal). 
+#' "DateTime" is the GMT date & time of each location in class \code{\link[base:DateTimeClasses]{POSIXct}} or \code{\link[base]{character}} with the following format "2012-06-03 01:33:46".
 #' "lat" and "lon" are the latitude and longitude of each location in decimal degrees. 
-#' "qi" is the numerical quality index associated with each location fix where a greater number indicates a higher accuracy 
-#' (e.g. the number of GPS satellites involved in estimation).
+#' "qi" is the quality index associated with each location fix. 
+#' The input values can be either the number of GPS satellites or Argos Location Classes. 
+#' Argos Location Classes will be converted to numerical values, where "A", "B", "Z" will be replaced with "-1", "-2", "-3" respectively.
+#' The greater number indicates a higher accuracy. 
 #' @importFrom dplyr distinct
 #' @export
 #' @details This is a partial component of \code{\link{dupfilter}}, although works as a stand-alone function.
@@ -21,9 +24,21 @@
   
 dupfilter_exact <- function(sdata){
   
-  #### Sample size for unfiltered data
+  ## Original sample size
   OriginalSS <- nrow(sdata)
-
+  
+  ## qi format
+  sdata <- within(sdata, {
+    qi[qi %in% "A"] <- "-1"
+    qi[qi %in% "B"] <- "-2"
+    qi[qi %in% "Z"] <- "-3"
+    qi <- as.numeric(as.character(qi))
+  })
+  
+  ## Date & time
+  sdata$DateTime <- with(sdata, as.POSIXct(DateTime, format = "%Y-%m-%d %H:%M:%S", tz = "GMT"))
+  
+  
   #### Filter temporally and spatially exact duplicates
   sdata <- dplyr::distinct(sdata, .data$id, .data$DateTime, .data$lat, .data$lon, .data$qi, .keep_all = TRUE)
 
